@@ -2,10 +2,15 @@ import argparse
 import asyncio
 import random
 import timeit
+from contextlib import suppress
+from os import wait
+
+import codefast as cf
 import requests
 from codefast.logger import Logger
-from contextlib import suppress
-logger = Logger(logname='/tmp/endlessh.log')
+from colorama import Back, Fore, Style
+
+logger = Logger('/tmp/endlessh.log')
 logger.level = 'INFO'
 
 
@@ -17,7 +22,7 @@ class Hosts:
         return sorted(cls.peer.items(), key=lambda p: p[1])
 
     @classmethod
-    def get_location(cls,ip: str) -> str:
+    def get_location(cls, ip: str) -> str:
         '''Returns the location of the ip address'''
         url = 'https://ipinfo.io/' + ip + '/json'
         with suppress(Exception):
@@ -25,20 +30,32 @@ class Hosts:
             return "{}, {}".format(resp['city'], resp['region'])
         return 'location unknown'
 
+    @classmethod
+    def get_connection_duraion(cls, peer: str) -> int:
+        '''Returns the connection duration of the peer'''
+        return timeit.default_timer() - cls.peer[peer]
+
 
 async def handler(_reader, writer):
     try:
         while True:
-            await asyncio.sleep(3)
             peer = ':'.join(
                 map(str, _reader._transport.get_extra_info('peername')))
             if peer not in Hosts.peer:
                 Hosts.peer[peer] = timeit.default_timer()
-                loc=Hosts.get_location(peer.split(':')[0])
-                logger.info('connection from peer {}, {}'.format(peer, loc))
+                loc = Hosts.get_location(peer.split(':')[0])
+                logger.info('connection from peer {}, {}'.format(
+                    peer, Fore.LIGHTMAGENTA_EX + loc))
             writer.write(b'%x\r\n' % random.randint(0, 2**32))
+            if int(peer.split(':').pop()) < 10000 and random.randint(
+                    0, 100) == 63:
+                logger.info(
+                    'MANUALLY close connection for peer {}'.format(peer))
+                writer.close()
+            await asyncio.sleep(3)
             await writer.drain()
-    except ConnectionResetError:
+    except Exception as e:
+        logger.info(e)
         logger.info(
             'connection closed by peer {} after [ {:.1f} ] seconds '.format(
                 peer,
